@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use Carp qw/longmess/;
 
-$Geoffrey::Exception::NotSupportedException::VERSION = '0.000201';
+$Geoffrey::Exception::NotSupportedException::VERSION = '0.000202';
 
 use Exception::Class 1.23 (
     'Geoffrey::Exception::NotSupportedException'           => { description => 'Unidentified exception', },
@@ -33,7 +33,8 @@ use Exception::Class 1.23 (
       { description => 'Any list information in converter is not supported!', },
     'Geoffrey::Exception::NotSupportedException::File' =>
       { description => 'Any subroutine information in file is not supported!', },
-
+    'Geoffrey::Exception::NotSupportedException::Changelog' =>
+      { description => 'Any subroutine in any action is not supported!', },
 );
 
 sub throw_empty_table {
@@ -61,7 +62,7 @@ sub throw_column {
         require Data::Dumper;
         my $s_params = Data::Dumper->new( [$hr_params] )->Terse(1)->Deparse(1)->Sortkeys(1)->Dump;
         return Geoffrey::Exception::NotSupportedException::Column->throw(
-        qq~Column type "$s_type" is not supported!\n$s_params\n$s_converter\n~ . longmess );
+            qq~Column type "$s_type" is not supported!\n$s_params\n$s_converter\n~ . longmess );
     }
     return Geoffrey::Exception::NotSupportedException::Column->throw(
         qq~Column type "$s_type" is not supported! $s_converter\n~ . longmess );
@@ -123,6 +124,11 @@ sub throw_action {
         qq~Subroutine in action is not supported!\n~ . longmess );
 }
 
+sub throw_changelog {
+    return Geoffrey::Exception::NotSupportedException::Changelog->throw(
+        qq~Subroutine in action is not supported!\n~ . longmess );
+}
+
 sub throw_list_information {
     my ( $s_subroutine, $s_converter ) = @_;
     return Geoffrey::Exception::NotSupportedException::ListInformation->throw(
@@ -186,6 +192,8 @@ version 0.000100
 
 =head2 throw_converter
 
+=head2 throw_changelog
+
 =head1 DIAGNOSTICS
 
 =head1 CONFIGURATION AND ENVIRONMENT
